diff --git a/src/util.h b/src/util.h
index 73f6f45c39eac8b1c5df094b5ce9d394ecc17279..45abe552052f6219847ebd6d6ff0e658ddc40c82 100644
--- a/src/util.h
+++ b/src/util.h
@@ -1,6 +1,6 @@
 /*!
 * \file    src/util.h
 * \brief   Header for popins2 utility functions
 *
 */
 #ifndef POPINS2_UTIL_H_
@@ -51,7 +51,7 @@ inline void printTimeStatus(const char * message){
         time_t now = time(0);
         struct tm tstruct;
         tstruct = *localtime(&now);
-        strftime(timestamp, sizeof(timestamp), "[popins2 %Y-%m-%d %X] ", &tstruct);
+        strftime(timestamp, sizeof(timestamp), "[popins4snake %Y-%m-%d %X] ", &tstruct);
 
         // Print time and message.
         std::cerr << timestamp << message << std::endl;
@@ -355,7 +355,7 @@ void printStatus(const char * message)
         time_t now = time(0);
         struct tm tstruct;
         tstruct = *localtime(&now);
-        strftime(timestamp, sizeof(timestamp), "[popins2 %Y-%m-%d %X] ", &tstruct);
+        strftime(timestamp, sizeof(timestamp), "[popins4snake %Y-%m-%d %X] ", &tstruct);
 
         // Print time and message.
         std::cerr << timestamp << message << std::endl;
@@ -1,6 +1,6 @@
 /*!
 * \file    src/util.h
-* \brief   Header for popins2 utility functions
+* \brief   Header for popins4snake utility functions
 *
 */